@@ -3,7 +3,7 @@ package Git::Code::Review::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '0.7'; # VERSION
+our $VERSION = '0.8'; # VERSION
 
 # Utility Modules
 use CLI::Helpers qw(:all);
@@ -34,6 +34,7 @@ use Sub::Exporter -setup => {
         gcr_open_editor
         gcr_view_commit
         gcr_view_commit_files
+        gcr_change_profile
         gcr_change_state
         gcr_not_resigned
         gcr_not_authored
@@ -231,17 +232,17 @@ sub gcr_reset {
     $type ||= 'audit';
     my $repo = gcr_repo($type);
     # Stash any local changes, and pull master
-    output({color=>'magenta'},"+ [$type] Reseting to origin:master, any changes will be stashed.");
+    verbose({color=>'magenta'},"+ [$type] Reseting to origin:master, any changes will be stashed.");
     my $origin = gcr_origin($type);
     if(defined $origin) {
-        verbose("= Found origin, checking working tree status.");
+        verbose({level=>2},"= Found origin, checking working tree status.");
         my @dirty = $repo->run(qw{status -s});
         if( @dirty ) {
-            output({color=>'yellow'},"! Audit working tree is dirty, stashing files");
+            verbose({color=>'yellow'},"! Audit working tree is dirty, stashing files");
             $repo->run($type eq 'audit' ? qw{stash -u} : qw(reset --hard));
         }
         if( $type eq 'audit' ) {
-            verbose({color=>'cyan'},"= Swithcing to master branch.");
+            verbose({level=>2,color=>'cyan'},"= Swithcing to master branch.");
             eval {
                 $repo->run(qw(checkout master));
             };
@@ -253,7 +254,7 @@ sub gcr_reset {
                 debug({color=>'red'}, "!! $err");
             }
         }
-        verbose({color=>'cyan'},"+ Initiating pull from $origin");
+        verbose({level=>2,color=>'cyan'},"+ Initiating pull from $origin");
         local *STDERR = *STDOUT;
         my @output = $repo->run(
             $type eq 'audit' ? qw(pull origin master) : 'pull'
@@ -396,6 +397,69 @@ sub gcr_view_commit_files {
 
 
 
+sub gcr_change_profile {
+    my($commit,$profile,$info) = @_;
+    my $audit = gcr_repo();
+    debug("gcr_change_profile('$commit->{sha1}','$profile')");
+
+    if(!ref $info) {
+        my %tmp;
+        $tmp{message} = $info;
+        $info = \%tmp;
+    }
+
+    # Already in profile
+    if ($commit->{profile} eq $profile) {
+        debug("! $commit->{sha1} is already in profile $profile, noop");
+        return;
+    }
+
+    # Validate Profile
+    my %profiles = gcr_profiles();
+    if(!exists $profiles{$profile}) {
+        output({stderr=>1,color=>"red"}, "Profile '$profile' doesn't exist. (Available: " . join(', ', sort keys %profiles));
+        exit 1;
+    }
+
+    # To / From
+    my $orig = $commit->{current_path};
+    my $prev = $commit->{profile};
+
+    # Build directories
+    my @path = File::Spec->splitdir($commit->{review_path});
+    my $file = pop @path;
+    splice @path, 0, 1, $profile;
+    gcr_mkdir(@path);
+
+    # Moves require that we keep the same base name
+    push @path, $commit->{base} unless $path[-1] eq $commit->{base};
+    my $target = File::Spec->catfile(@path);
+
+    pop @path;  # Remove the filename from the path
+    gcr_mkdir(@path);
+    if( $orig ne $target ) {
+        verbose("+ Moving from $orig to $target : $info->{message}");
+        debug($audit->run('mv', $orig, $target));
+        my %details = (
+            status => 'move',
+            profile_previous => $prev,
+            profile => $profile,
+            %$info
+        );
+        my $message = gcr_commit_message($commit,\%details);
+        $audit->run('commit', '-m', $message);
+        gcr_push();
+    }
+    else {
+        debug("gcr_change_profile() already at $target");
+    }
+
+    $commit->{profile} = $profile;
+    $commit->{current_path} = $target;
+}
+
+
+
 sub gcr_change_state {
     my($commit,$state,$info) = @_;
     my $audit = gcr_repo();
@@ -459,6 +523,7 @@ sub gcr_change_state {
     $commit->{current_path} = $target;
 }
 
+
 sub gcr_commit_message {
     my($commit,$info) = @_;
     my %details = ();
@@ -594,7 +659,7 @@ Git::Code::Review::Utilities - Tools for performing code review using Git as the
 
 =head1 VERSION
 
-version 0.7
+version 0.8
 
 =head1 FUNCTIONS
 
@@ -666,6 +731,14 @@ stores time spent in editor as review_time in the hash.
 Display a menu containing the files mentioned in the commit with the ability to view
 the contents of one of those files.
 
+=head2 gcr_change_profile($commit_info,$profile,$details)
+
+$commit_info is a hash attained from gcr_commit_info()
+$profile is a string representing the desired profile
+$details can be either a string, the commit message, or a hash reference
+including a 'message' item to become the commit message.  The rest of the keys
+will be added to the YAML generated.
+
 =head2 gcr_change_state($commit_info,$state,$details)
 
 $commit_info is a hash attained from gcr_commit_info()
